@@ -66,14 +66,14 @@ class Filtration:
         self.cl_index = self.cl.zeros(
             INDEX_SIZE, np.uint32)
 
-        work_items = (to_multiple(queries_size, self.blocksize), self.queries_width, 16)
-        # TODO below fails if blocksize is smaller than queries_width
         dim0 = self.blocksize // (self.queries_width * 16)
         if not dim0:
             dim0 = 1
         elif dim0 % 2:
             dim0 += 1
+        work_items = (to_multiple(queries_size, dim0), self.queries_width, 16)
         work_groups = dim0, self.queries_width, 16
+        logging.debug("Kernel config of q-group index building: {}; {}".format(work_items, work_groups))
         self.cl.filtration.create_queries_index(
             self.cl.queue,
             work_items,
